==> OSCA.workflows_1.14.0.tar.gz: OSCA.workflows/inst/doc/book/muraro-pancreas.md <==
# Muraro human pancreas (CEL-seq)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @muraro2016singlecell CEL-seq dataset,
consisting of human pancreas cells from various donors.

## Data loading


``` r
library(scRNAseq)
sce.muraro <- MuraroPancreasData()
```

Converting back to Ensembl identifiers.


``` r
library(AnnotationHub)
edb <- AnnotationHub()[["AH73881"]]
gene.symb <- sub("__chr.*$", "", rownames(sce.muraro))
gene.ids <- mapIds(edb, keys=gene.symb, 
    keytype="SYMBOL", column="GENEID")

# Removing duplicated genes or genes without Ensembl IDs.
keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.muraro <- sce.muraro[keep,]
rownames(sce.muraro) <- gene.ids[keep]
```

## Quality control


``` r
unfiltered <- sce.muraro
```

This dataset lacks mitochondrial genes so we will do without.
For the one batch that seems to have a high proportion of low-quality cells, we compute an appropriate filter threshold using a shared median and MAD from the other batches (Figure \@ref(fig:unref-muraro-qc-dist)).


``` r
library(scater)
stats <- perCellQCMetrics(sce.muraro)
qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.muraro$donor, subset=sce.muraro$donor!="D28")
sce.muraro <- sce.muraro[,!qc$discard]
```


``` r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-muraro-qc-dist)Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>

We have a look at the causes of removal:


``` r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       663                       700                       738 
##                   discard 
##                       773
```

## Normalization


``` r
library(scran)
set.seed(1000)
clusters <- quickCluster(sce.muraro)
sce.muraro <- computeSumFactors(sce.muraro, clusters=clusters)
sce.muraro <- logNormCounts(sce.muraro)
```


``` r
summary(sizeFactors(sce.muraro))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.088   0.541   0.821   1.000   1.211  13.987
```


``` r
plot(librarySizeFactors(sce.muraro), sizeFactors(sce.muraro), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-muraro-norm)Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


``` r
block <- paste0(sce.muraro$plate, "_", sce.muraro$donor)
dec.muraro <- modelGeneVarWithSpikes(sce.muraro, "ERCC", block=block)
top.muraro <- getTopHVGs(dec.muraro, prop=0.1)
```


``` r
par(mfrow=c(8,4))
blocked.stats <- dec.muraro$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-muraro-variance)Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


``` r
library(batchelor)
set.seed(1001010)
merged.muraro <- fastMNN(sce.muraro, subset.row=top.muraro, 
    batch=sce.muraro$donor)
```

We use the proportion of variance lost as a diagnostic measure:


``` r
metadata(merged.muraro)$merge.info$lost.var
```

```
##           D28      D29      D30     D31
## [1,] 0.060847 0.024121 0.000000 0.00000
## [2,] 0.002646 0.003018 0.062421 0.00000
## [3,] 0.003449 0.002641 0.002598 0.08162
```

## Dimensionality reduction


``` r
set.seed(100111)
merged.muraro <- runTSNE(merged.muraro, dimred="corrected")
```

## Clustering


``` r
snn.gr <- buildSNNGraph(merged.muraro, use.dimred="corrected")
colLabels(merged.muraro) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


``` r
tab <- table(Cluster=colLabels(merged.muraro), CellType=sce.muraro$label)
library(pheatmap)
pheatmap(log10(tab+10), color=viridis::viridis(100))
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-seger-heat-1.png" alt="Heatmap of the frequency of cells from each cell type label in each cluster." width="672" />
<p class="caption">(\#fig:unref-seger-heat)Heatmap of the frequency of cells from each cell type label in each cluster.</p>
</div>


``` r
table(Cluster=colLabels(merged.muraro), Donor=merged.muraro$batch)
```

```
##        Donor
## Cluster D28 D29 D30 D31
##      1  104   6  57 112
##      2   59  21  77  97
##      3   12  75  64  43
##      4   28 149 126 120
##      5   87 261 277 214
##      6   21   7  54  26
##      7    1   6   6  37
##      8    6   6   5   2
##      9   11  68   5  30
##      10   4   2   5   8
```


``` r
gridExtra::grid.arrange(
    plotTSNE(merged.muraro, colour_by="label"),
    plotTSNE(merged.muraro, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-tsne-1.png" alt="Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-muraro-tsne)Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R version 4.4.1 (2024-06-14)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.1 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.20-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] pheatmap_1.0.12             batchelor_1.22.0           
 [3] scran_1.34.0                scater_1.34.0              
 [5] ggplot2_3.5.1               scuttle_1.16.0             
 [7] ensembldb_2.30.0            AnnotationFilter_1.30.0    
 [9] GenomicFeatures_1.58.0      AnnotationDbi_1.68.0       
[11] AnnotationHub_3.14.0        BiocFileCache_2.14.0       
[13] dbplyr_2.5.0                scRNAseq_2.19.1            
[15] SingleCellExperiment_1.28.0 SummarizedExperiment_1.36.0
[17] Biobase_2.66.0              GenomicRanges_1.58.0       
[19] GenomeInfoDb_1.42.0         IRanges_2.40.0             
[21] S4Vectors_0.44.0            BiocGenerics_0.52.0        
[23] MatrixGenerics_1.18.0       matrixStats_1.4.1          
[25] BiocStyle_2.34.0            rebook_1.16.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_1.8.9           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          gypsum_1.2.0             
  [7] farver_2.1.2              rmarkdown_2.28           
  [9] BiocIO_1.16.0             zlibbioc_1.52.0          
 [11] vctrs_0.6.5               DelayedMatrixStats_1.28.0
 [13] memoise_2.0.1             Rsamtools_2.22.0         
 [15] RCurl_1.98-1.16           htmltools_0.5.8.1        
 [17] S4Arrays_1.6.0            curl_5.2.3               
 [19] BiocNeighbors_2.0.0       Rhdf5lib_1.28.0          
 [21] SparseArray_1.6.0         rhdf5_2.50.0             
 [23] sass_0.4.9                alabaster.base_1.6.0     
 [25] bslib_0.8.0               alabaster.sce_1.6.0      
 [27] httr2_1.0.5               cachem_1.1.0             
 [29] ResidualMatrix_1.16.0     GenomicAlignments_1.42.0 
 [31] igraph_2.1.1              mime_0.12                
 [33] lifecycle_1.0.4           pkgconfig_2.0.3          
 [35] rsvd_1.0.5                Matrix_1.7-1             
 [37] R6_2.5.1                  fastmap_1.2.0            
 [39] GenomeInfoDbData_1.2.13   digest_0.6.37            
 [41] colorspace_2.1-1          dqrng_0.4.1              
 [43] irlba_2.3.5.1             ExperimentHub_2.14.0     
 [45] RSQLite_2.3.7             beachmat_2.22.0          
 [47] labeling_0.4.3            filelock_1.0.3           
 [49] fansi_1.0.6               httr_1.4.7               
 [51] abind_1.4-8               compiler_4.4.1           
 [53] bit64_4.5.2               withr_3.0.2              
 [55] BiocParallel_1.40.0       viridis_0.6.5            
 [57] DBI_1.2.3                 highr_0.11               
 [59] HDF5Array_1.34.0          alabaster.ranges_1.6.0   
 [61] alabaster.schemas_1.6.0   rappdirs_0.3.3           
 [63] DelayedArray_0.32.0       bluster_1.16.0           
 [65] rjson_0.2.23              tools_4.4.1              
 [67] vipor_0.4.7               beeswarm_0.4.0           
 [69] glue_1.8.0                restfulr_0.0.15          
 [71] rhdf5filters_1.18.0       grid_4.4.1               
 [73] Rtsne_0.17                cluster_2.1.6            
 [75] generics_0.1.3            gtable_0.3.6             
 [77] metapod_1.14.0            BiocSingular_1.22.0      
 [79] ScaledMatrix_1.14.0       utf8_1.2.4               
 [81] XVector_0.46.0            ggrepel_0.9.6            
 [83] BiocVersion_3.20.0        pillar_1.9.0             
 [85] limma_3.62.0              dplyr_1.1.4              
 [87] lattice_0.22-6            rtracklayer_1.66.0       
 [89] bit_4.5.0                 tidyselect_1.2.1         
 [91] locfit_1.5-9.10           Biostrings_2.74.0        
 [93] knitr_1.48                gridExtra_2.3            
 [95] bookdown_0.41             ProtGenerics_1.38.0      
 [97] edgeR_4.4.0               xfun_0.48                
 [99] statmod_1.5.0             UCSC.utils_1.2.0         
[101] lazyeval_0.2.2            yaml_2.3.10              
[103] evaluate_1.0.1            codetools_0.2-20         
[105] tibble_3.2.1              alabaster.matrix_1.6.0   
[107] BiocManager_1.30.25       graph_1.84.0             
[109] cli_3.6.3                 munsell_0.5.1            
[111] jquerylib_0.1.4           Rcpp_1.0.13              
[113] dir.expiry_1.14.0         png_0.1-8                
[115] XML_3.99-0.17             parallel_4.4.1           
[117] blob_1.2.4                sparseMatrixStats_1.18.0 
[119] bitops_1.0-9              viridisLite_0.4.2        
[121] alabaster.se_1.6.0        scales_1.3.0             
[123] purrr_1.0.2               crayon_1.5.3             
[125] rlang_1.1.4               cowplot_1.1.3            
[127] KEGGREST_1.46.0          
```
</div>

==> OSCA.workflows_1.15.0.tar.gz: OSCA.workflows/inst/doc/book/muraro-pancreas.md <==
# Muraro human pancreas (CEL-seq)

<script>
document.addEventListener("click", function (event) {
    if (event.target.classList.contains("rebook-collapse")) {
        event.target.classList.toggle("active");
        var content = event.target.nextElementSibling;
        if (content.style.display === "block") {
            content.style.display = "none";
        } else {
            content.style.display = "block";
        }
    }
})
</script>

<style>
.rebook-collapse {
  background-color: #eee;
  color: #444;
  cursor: pointer;
  padding: 18px;
  width: 100%;
  border: none;
  text-align: left;
  outline: none;
  font-size: 15px;
}

.rebook-content {
  padding: 0 18px;
  display: none;
  overflow: hidden;
  background-color: #f1f1f1;
}
</style>

## Introduction

This performs an analysis of the @muraro2016singlecell CEL-seq dataset,
consisting of human pancreas cells from various donors.

## Data loading


``` r
library(scRNAseq)
sce.muraro <- MuraroPancreasData()
```

Converting back to Ensembl identifiers.


``` r
library(AnnotationHub)
edb <- AnnotationHub()[["AH73881"]]
gene.symb <- sub("__chr.*$", "", rownames(sce.muraro))
gene.ids <- mapIds(edb, keys=gene.symb, 
    keytype="SYMBOL", column="GENEID")

# Removing duplicated genes or genes without Ensembl IDs.
keep <- !is.na(gene.ids) & !duplicated(gene.ids)
sce.muraro <- sce.muraro[keep,]
rownames(sce.muraro) <- gene.ids[keep]
```

## Quality control


``` r
unfiltered <- sce.muraro
```

This dataset lacks mitochondrial genes so we will do without.
For the one batch that seems to have a high proportion of low-quality cells, we compute an appropriate filter threshold using a shared median and MAD from the other batches (Figure \@ref(fig:unref-muraro-qc-dist)).


``` r
library(scater)
stats <- perCellQCMetrics(sce.muraro)
qc <- quickPerCellQC(stats, percent_subsets="altexps_ERCC_percent",
    batch=sce.muraro$donor, subset=sce.muraro$donor!="D28")
sce.muraro <- sce.muraro[,!qc$discard]
```


``` r
colData(unfiltered) <- cbind(colData(unfiltered), stats)
unfiltered$discard <- qc$discard

gridExtra::grid.arrange(
    plotColData(unfiltered, x="donor", y="sum", colour_by="discard") +
        scale_y_log10() + ggtitle("Total count"),
    plotColData(unfiltered, x="donor", y="detected", colour_by="discard") +
        scale_y_log10() + ggtitle("Detected features"),
    plotColData(unfiltered, x="donor", y="altexps_ERCC_percent",
        colour_by="discard") + ggtitle("ERCC percent"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-qc-dist-1.png" alt="Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded." width="672" />
<p class="caption">(\#fig:unref-muraro-qc-dist)Distribution of each QC metric across cells from each donor in the Muraro pancreas dataset. Each point represents a cell and is colored according to whether that cell was discarded.</p>
</div>

We have a look at the causes of removal:


``` r
colSums(as.matrix(qc))
```

```
##              low_lib_size            low_n_features high_altexps_ERCC_percent 
##                       663                       700                       738 
##                   discard 
##                       773
```

## Normalization


``` r
library(scran)
set.seed(1000)
clusters <- quickCluster(sce.muraro)
sce.muraro <- computeSumFactors(sce.muraro, clusters=clusters)
sce.muraro <- logNormCounts(sce.muraro)
```


``` r
summary(sizeFactors(sce.muraro))
```

```
##    Min. 1st Qu.  Median    Mean 3rd Qu.    Max. 
##   0.088   0.541   0.821   1.000   1.211  13.987
```


``` r
plot(librarySizeFactors(sce.muraro), sizeFactors(sce.muraro), pch=16,
    xlab="Library size factors", ylab="Deconvolution factors", log="xy")
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-norm-1.png" alt="Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset." width="672" />
<p class="caption">(\#fig:unref-muraro-norm)Relationship between the library size factors and the deconvolution size factors in the Muraro pancreas dataset.</p>
</div>

## Variance modelling

We block on a combined plate and donor factor.


``` r
block <- paste0(sce.muraro$plate, "_", sce.muraro$donor)
dec.muraro <- modelGeneVarWithSpikes(sce.muraro, "ERCC", block=block)
top.muraro <- getTopHVGs(dec.muraro, prop=0.1)
```


``` r
par(mfrow=c(8,4))
blocked.stats <- dec.muraro$per.block
for (i in colnames(blocked.stats)) {
    current <- blocked.stats[[i]]
    plot(current$mean, current$total, main=i, pch=16, cex=0.5,
        xlab="Mean of log-expression", ylab="Variance of log-expression")
    curfit <- metadata(current)
    points(curfit$mean, curfit$var, col="red", pch=16)
    curve(curfit$trend(x), col='dodgerblue', add=TRUE, lwd=2)
}
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-variance-1.png" alt="Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor." width="672" />
<p class="caption">(\#fig:unref-muraro-variance)Per-gene variance as a function of the mean for the log-expression values in the Muraro pancreas dataset. Each point represents a gene (black) with the mean-variance trend (blue) fitted to the spike-in transcripts (red) separately for each donor.</p>
</div>

## Data integration


``` r
library(batchelor)
set.seed(1001010)
merged.muraro <- fastMNN(sce.muraro, subset.row=top.muraro, 
    batch=sce.muraro$donor)
```

We use the proportion of variance lost as a diagnostic measure:


``` r
metadata(merged.muraro)$merge.info$lost.var
```

```
##           D28      D29      D30     D31
## [1,] 0.060847 0.024121 0.000000 0.00000
## [2,] 0.002646 0.003018 0.062421 0.00000
## [3,] 0.003449 0.002641 0.002598 0.08162
```

## Dimensionality reduction


``` r
set.seed(100111)
merged.muraro <- runTSNE(merged.muraro, dimred="corrected")
```

## Clustering


``` r
snn.gr <- buildSNNGraph(merged.muraro, use.dimred="corrected")
colLabels(merged.muraro) <- factor(igraph::cluster_walktrap(snn.gr)$membership)
```


``` r
tab <- table(Cluster=colLabels(merged.muraro), CellType=sce.muraro$label)
library(pheatmap)
pheatmap(log10(tab+10), color=viridis::viridis(100))
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-seger-heat-1.png" alt="Heatmap of the frequency of cells from each cell type label in each cluster." width="672" />
<p class="caption">(\#fig:unref-seger-heat)Heatmap of the frequency of cells from each cell type label in each cluster.</p>
</div>


``` r
table(Cluster=colLabels(merged.muraro), Donor=merged.muraro$batch)
```

```
##        Donor
## Cluster D28 D29 D30 D31
##      1  104   6  57 112
##      2   59  21  77  97
##      3   12  75  64  43
##      4   28 149 126 120
##      5   87 261 277 214
##      6   21   7  54  26
##      7    1   6   6  37
##      8    6   6   5   2
##      9   11  68   5  30
##      10   4   2   5   8
```


``` r
gridExtra::grid.arrange(
    plotTSNE(merged.muraro, colour_by="label"),
    plotTSNE(merged.muraro, colour_by="batch"),
    ncol=2
)
```

<div class="figure">
<img src="muraro-pancreas_files/figure-html/unref-muraro-tsne-1.png" alt="Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right)." width="672" />
<p class="caption">(\#fig:unref-muraro-tsne)Obligatory $t$-SNE plots of the Muraro pancreas dataset. Each point represents a cell that is colored by cluster (left) or batch (right).</p>
</div>

## Session Info {-}

<button class="rebook-collapse">View session info</button>
<div class="rebook-content">
```
R Under development (unstable) (2024-10-21 r87258)
Platform: x86_64-pc-linux-gnu
Running under: Ubuntu 24.04.1 LTS

Matrix products: default
BLAS:   /home/biocbuild/bbs-3.21-bioc/R/lib/libRblas.so 
LAPACK: /usr/lib/x86_64-linux-gnu/lapack/liblapack.so.3.12.0

locale:
 [1] LC_CTYPE=en_US.UTF-8       LC_NUMERIC=C              
 [3] LC_TIME=en_GB              LC_COLLATE=C              
 [5] LC_MONETARY=en_US.UTF-8    LC_MESSAGES=en_US.UTF-8   
 [7] LC_PAPER=en_US.UTF-8       LC_NAME=C                 
 [9] LC_ADDRESS=C               LC_TELEPHONE=C            
[11] LC_MEASUREMENT=en_US.UTF-8 LC_IDENTIFICATION=C       

time zone: America/New_York
tzcode source: system (glibc)

attached base packages:
[1] stats4    stats     graphics  grDevices utils     datasets  methods  
[8] base     

other attached packages:
 [1] pheatmap_1.0.12             batchelor_1.23.0           
 [3] scran_1.35.0                scater_1.35.0              
 [5] ggplot2_3.5.1               scuttle_1.17.0             
 [7] ensembldb_2.31.0            AnnotationFilter_1.31.0    
 [9] GenomicFeatures_1.59.1      AnnotationDbi_1.69.0       
[11] AnnotationHub_3.15.0        BiocFileCache_2.15.0       
[13] dbplyr_2.5.0                scRNAseq_2.21.0            
[15] SingleCellExperiment_1.29.1 SummarizedExperiment_1.37.0
[17] Biobase_2.67.0              GenomicRanges_1.59.0       
[19] GenomeInfoDb_1.43.0         IRanges_2.41.0             
[21] S4Vectors_0.45.1            BiocGenerics_0.53.1        
[23] generics_0.1.3              MatrixGenerics_1.19.0      
[25] matrixStats_1.4.1           BiocStyle_2.35.0           
[27] rebook_1.17.0              

loaded via a namespace (and not attached):
  [1] RColorBrewer_1.1-3        jsonlite_1.8.9           
  [3] CodeDepends_0.6.6         magrittr_2.0.3           
  [5] ggbeeswarm_0.7.2          gypsum_1.3.0             
  [7] farver_2.1.2              rmarkdown_2.29           
  [9] BiocIO_1.17.0             zlibbioc_1.53.0          
 [11] vctrs_0.6.5               DelayedMatrixStats_1.29.0
 [13] memoise_2.0.1             Rsamtools_2.23.0         
 [15] RCurl_1.98-1.16           htmltools_0.5.8.1        
 [17] S4Arrays_1.7.1            curl_6.0.0               
 [19] BiocNeighbors_2.1.0       Rhdf5lib_1.29.0          
 [21] SparseArray_1.7.1         rhdf5_2.51.0             
 [23] sass_0.4.9                alabaster.base_1.7.1     
 [25] bslib_0.8.0               alabaster.sce_1.7.0      
 [27] httr2_1.0.6               cachem_1.1.0             
 [29] ResidualMatrix_1.17.0     GenomicAlignments_1.43.0 
 [31] igraph_2.1.1              mime_0.12                
 [33] lifecycle_1.0.4           pkgconfig_2.0.3          
 [35] rsvd_1.0.5                Matrix_1.7-1             
 [37] R6_2.5.1                  fastmap_1.2.0            
 [39] GenomeInfoDbData_1.2.13   digest_0.6.37            
 [41] colorspace_2.1-1          dqrng_0.4.1              
 [43] irlba_2.3.5.1             ExperimentHub_2.15.0     
 [45] RSQLite_2.3.7             beachmat_2.23.0          
 [47] labeling_0.4.3            filelock_1.0.3           
 [49] fansi_1.0.6               httr_1.4.7               
 [51] abind_1.4-8               compiler_4.5.0           
 [53] bit64_4.5.2               withr_3.0.2              
 [55] BiocParallel_1.41.0       viridis_0.6.5            
 [57] DBI_1.2.3                 HDF5Array_1.35.1         
 [59] alabaster.ranges_1.7.0    alabaster.schemas_1.7.0  
 [61] rappdirs_0.3.3            DelayedArray_0.33.1      
 [63] bluster_1.17.0            rjson_0.2.23             
 [65] tools_4.5.0               vipor_0.4.7              
 [67] beeswarm_0.4.0            glue_1.8.0               
 [69] restfulr_0.0.15           rhdf5filters_1.19.0      
 [71] grid_4.5.0                Rtsne_0.17               
 [73] cluster_2.1.6             gtable_0.3.6             
 [75] metapod_1.15.0            BiocSingular_1.23.0      
 [77] ScaledMatrix_1.15.0       utf8_1.2.4               
 [79] XVector_0.47.0            ggrepel_0.9.6            
 [81] BiocVersion_3.21.1        pillar_1.9.0             
 [83] limma_3.63.2              dplyr_1.1.4              
 [85] lattice_0.22-6            rtracklayer_1.67.0       
 [87] bit_4.5.0                 tidyselect_1.2.1         
 [89] locfit_1.5-9.10           Biostrings_2.75.1        
 [91] knitr_1.49                gridExtra_2.3            
 [93] bookdown_0.41             ProtGenerics_1.39.0      
 [95] edgeR_4.5.0               xfun_0.49                
 [97] statmod_1.5.0             UCSC.utils_1.3.0         
 [99] lazyeval_0.2.2            yaml_2.3.10              
[101] evaluate_1.0.1            codetools_0.2-20         
[103] tibble_3.2.1              alabaster.matrix_1.7.0   
[105] BiocManager_1.30.25       graph_1.85.0             
[107] cli_3.6.3                 munsell_0.5.1            
[109] jquerylib_0.1.4           Rcpp_1.0.13-1            
[111] dir.expiry_1.15.0         png_0.1-8                
[113] XML_3.99-0.17             parallel_4.5.0           
[115] blob_1.2.4                sparseMatrixStats_1.19.0 
[117] bitops_1.0-9              viridisLite_0.4.2        
[119] alabaster.se_1.7.0        scales_1.3.0             
[121] purrr_1.0.2               crayon_1.5.3             
[123] rlang_1.1.4               cowplot_1.1.3            
[125] KEGGREST_1.47.0          
```
</div>
